@@ -934,6 +934,10 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         opt->gearman_connection_timeout = atoi( value );
     }
 
+    else if ( !strcmp( key, "prometheus_server" ) ) {
+        gm_log( GM_LOG_INFO, "ignoring unsupported option '%s'\n", key );
+    }
+
     else {
         gm_log( GM_LOG_ERROR, "unknown option '%s'\n", key );
     }
@@ -1591,8 +1595,7 @@ void send_result_back(gm_job_t * exec_job) {
                          temp_buffer1,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode,
-                         TRUE
+                         mod_gm_opt->transportmode
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
     }
@@ -1614,8 +1617,7 @@ void send_result_back(gm_job_t * exec_job) {
                               temp_buffer2,
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
-                              mod_gm_opt->transportmode,
-                              TRUE
+                              mod_gm_opt->transportmode
                             ) == GM_OK) {
             gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
         }
