@@ -356,8 +356,7 @@ int submit_result() {
                          result,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
-                         mod_gm_opt->transportmode,
-                         TRUE
+                         mod_gm_opt->transportmode
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
 
@@ -369,8 +368,7 @@ int submit_result() {
                                  result,
                                  GM_JOB_PRIO_NORMAL,
                                  GM_DEFAULT_JOB_RETRIES,
-                                 mod_gm_opt->transportmode,
-                                 TRUE
+                                 mod_gm_opt->transportmode
                             ) == GM_OK) {
                 gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
             }
